InitializationSettings class

Settings for initializing the plugin for each platform.

Constructors

InitializationSettings({AndroidInitializationSettings? android, DarwinInitializationSettings? iOS, DarwinInitializationSettings? macOS, LinuxInitializationSettings? linux})
Constructs an instance of InitializationSettings.
const

Properties

android → AndroidInitializationSettings?
Settings for Android.
final
hashCode → int
The hash code for this object.
no setterinherited
iOS → DarwinInitializationSettings?
Settings for iOS.
final
linux → LinuxInitializationSettings?
Settings for Linux.
final
macOS → DarwinInitializationSettings?
Settings for macOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited