NotificationUtils class

Constructors

NotificationUtils()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeSelfStarting() → void
关闭自启动
enableSelfStarting() → void
启用自启动
isCloseSelfStarting() → Future<bool?>
是否关闭自启动
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRescheduleNotifications() → void
注册自启动通知广播【仅Android平台】
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → NotificationUtils
no setter