AudioAttributesUsage class

The available audio attributes usages for an Android service.

Annotations

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The integer representation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

values → List<AudioAttributesUsage>
All the possible values for the AudioAttributesUsage enumeration.
no setter