Priority class

Priority for notifications on Android 7.1 and lower.

Annotations

Constructors

Priority(int value)
Constructs an instance of Priority.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The integer representation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

values → List<Priority>
All the possible values for the Priority enumeration.
no setter

Constants

defaultPriority → const Priority
Default.
high → const Priority
High.
low → const Priority
Low.
max → const Priority
Max.
min → const Priority
Min.