AndroidInitializationSettings class

Plugin initialization settings for Android.

Available extensions

Constructors

AndroidInitializationSettings(String defaultIcon)
Constructs an instance of AndroidInitializationSettings.
const

Properties

defaultIcon → String
Specifies the default icon for notifications.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>

Available on AndroidInitializationSettings, provided by the AndroidInitializationSettingsMapper extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited