DarwinInitializationSettings class

Plugin initialization settings for Darwin-based operating systems such as iOS and macOS

Available extensions

Constructors

DarwinInitializationSettings({bool requestAlertPermission = true, bool requestSoundPermission = true, bool requestBadgePermission = true, bool requestCriticalPermission = false, bool defaultPresentAlert = true, bool defaultPresentSound = true, bool defaultPresentBadge = true, DidReceiveLocalNotificationCallback? onDidReceiveLocalNotification, List<DarwinNotificationCategory> notificationCategories = const <DarwinNotificationCategory>[]})
Constructs an instance of DarwinInitializationSettings.
const

Properties

defaultPresentAlert → bool
Configures the default setting on if an alert should be displayed when a notification is triggered while app is in the foreground.
final
defaultPresentBadge → bool
Configures the default setting on if a badge value should be applied when a notification is triggered while app is in the foreground by default.
final
defaultPresentSound → bool
Configures the default setting on if a sound should be played when a notification is triggered while app is in the foreground by default.
final
hashCode → int
The hash code for this object.
no setterinherited
notificationCategories → List<DarwinNotificationCategory>
Configure the notification categories (DarwinNotificationCategory) available. This allows for fine-tuning of preview display.
final
onDidReceiveLocalNotification → DidReceiveLocalNotificationCallback?
Callback for handling when a notification is triggered while the app is in the foreground.
final
requestAlertPermission → bool
Request permission to display an alert.
final
requestBadgePermission → bool
Request permission to badge app icon.
final
requestCriticalPermission → bool
Request permission to show critical notifications.
final
requestSoundPermission → bool
Request permission to play a sound.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>

Available on DarwinInitializationSettings, provided by the DarwinInitializationSettingsMapper extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited