Time class

Used for specifying a time in 24 hour format.

Available extensions

Constructors

Time([int hour = 0, int minute = 0, int second = 0])
Constructs an instance of Time.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour → int
The hour component of the time.
final
minute → int
The minutes component of the time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
The seconds component of the time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, int>

Available on Time, provided by the TimeMapper extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited